Stan Math Library: stan/math/prim/mat/fun/rank.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
rank.hpp File Reference
`#include <stan/math/prim/mat/err/check_range.hpp>`
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <vector>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T >
int | stan::math::rank (const std::vector< T > &v, int s)
| Return the number of components of v less than v[s]. More...
template<typename T , int R, int C>
int | stan::math::rank (const Eigen::Matrix< T, R, C > &v, int s)
| Return the number of components of v less than v[s]. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.